﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Reflection;
using System.IO;
using System.Text;
using System.Security.Cryptography;

namespace RSAManaged.SilverlightTestApp
{
    public partial class MainPage : UserControl
    {
        RSAPublicKey _publicKey = null;
        RSAPrivateKey _privateKey = null;

        public MainPage()
        {
            InitializeComponent();

            string privateKeyXmlString = new StreamReader(Assembly.GetExecutingAssembly().GetManifestResourceStream("RSAManaged.SilverlightTestApp.RSA.PrivateKey.xml")).ReadToEnd();
            string publicKeyXmlString = new StreamReader(Assembly.GetExecutingAssembly().GetManifestResourceStream("RSAManaged.SilverlightTestApp.RSA.PublicKey.xml")).ReadToEnd();
            this._privateKey = RSAPrivateKey.FromXmlString(privateKeyXmlString);
            this._publicKey = RSAPublicKey.FromXmlString(publicKeyXmlString);
        }

        private void btnPrivateKeyEncrypt_Click(object sender, RoutedEventArgs e)
        {
            string input = this.txtInput.Text;
            byte[] inputData = Encoding.UTF8.GetBytes(input);

            DateTime d1 = DateTime.Now;
            byte[] inputDateEnc = RSAManaged.Encrypt(inputData, this._privateKey);
            TimeSpan t1 = DateTime.Now - d1;
            System.Diagnostics.Debug.WriteLine("Private Key Encrypt:{0}", t1);

            DateTime d2 = DateTime.Now;
            byte[] inputDataDec = RSAManaged.Decrypt(inputDateEnc, this._publicKey);
            TimeSpan t2 = DateTime.Now - d2;
            System.Diagnostics.Debug.WriteLine("Public Key Decrypt:{0}", t2);

            string inputDec = Encoding.UTF8.GetString(inputDataDec, 0, inputDataDec.Length);

            MessageBox.Show(string.Format("Public Key Decrypt Result:{0}", inputDec));
        }

        private void btnPublicKeyEncrypt_Click(object sender, RoutedEventArgs e)
        {
            string input = this.txtInput.Text;
            byte[] inputData = Encoding.UTF8.GetBytes(input);

            DateTime d1 = DateTime.Now;
            byte[] inputDateEnc = RSAManaged.Encrypt(inputData, this._publicKey);
            TimeSpan t1 = DateTime.Now - d1;
            System.Diagnostics.Debug.WriteLine("Public Key Encrypt:{0}", t1);

            DateTime d2 = DateTime.Now;
            byte[] inputDataDec = RSAManaged.Decrypt(inputDateEnc, this._privateKey);
            TimeSpan t2 = DateTime.Now - d2;
            System.Diagnostics.Debug.WriteLine("Private Key Decrypt:{0}", t2);

            string inputDec = Encoding.UTF8.GetString(inputDataDec, 0, inputDataDec.Length);

            MessageBox.Show(string.Format("Private Key Decrypt Result:{0}", inputDec));
        }

        private void btnPrivateKeySign_Click(object sender, RoutedEventArgs e)
        {
            string input = this.txtInput.Text;
            byte[] inputData = Encoding.UTF8.GetBytes(input);
            SHA1Managed sha1 = new SHA1Managed();

            DateTime d1 = DateTime.Now;
            byte[] signature = RSAManaged.Sign(inputData, this._privateKey, sha1);
            TimeSpan t1 = DateTime.Now - d1;
            System.Diagnostics.Debug.WriteLine("Private Key Sign Data:{0}", t1);

            DateTime d2 = DateTime.Now;
            bool result = RSAManaged.Verify(inputData, this._publicKey, sha1, signature);
            TimeSpan t2 = DateTime.Now - d2;
            System.Diagnostics.Debug.WriteLine("Public Key Verify Data:{0}", t2);

            sha1.Clear();
            MessageBox.Show(string.Format("Public Key Verify Result:{0}", result));
        }

        private void btnPublicKeySign_Click(object sender, RoutedEventArgs e)
        {
            string input = this.txtInput.Text;
            byte[] inputData = Encoding.UTF8.GetBytes(input);
            SHA1Managed sha1 = new SHA1Managed();

            DateTime d1 = DateTime.Now;
            byte[] signature = RSAManaged.Sign(inputData, this._publicKey, sha1);
            TimeSpan t1 = DateTime.Now - d1;
            System.Diagnostics.Debug.WriteLine("Public Key Sign Data:{0}", t1);

            DateTime d2 = DateTime.Now;
            bool result = RSAManaged.Verify(inputData, this._privateKey, sha1, signature);
            TimeSpan t2 = DateTime.Now - d2;
            System.Diagnostics.Debug.WriteLine("Private Key Verify Data:{0}", t2);

            sha1.Clear();
            MessageBox.Show(string.Format("Private Key Verify Result:{0}", result));
        }
    }
}
